@@ -24,6 +24,9 @@
  * @author     Yuliya Bozhko <yuliya.bozhko@totaralms.com>
  */
 
+define('AJAX_SCRIPT', true);
+define('NO_MOODLE_COOKIES', true); // No need for a session here.
+
 require_once(dirname(dirname(__FILE__)) . '/config.php');
 require_once($CFG->libdir . '/badgeslib.php');
 
@@ -35,6 +38,5 @@ $hash = required_param('b', PARAM_ALPHANUM);
 
 $badge = badges_get_issued_badge_info($hash);
 
-header('Content-type: application/json; charset=utf-8');
-
-echo json_encode($badge);
\ No newline at end of file
+echo $OUTPUT->header();
+echo json_encode($badge);
