@@ -75,19 +75,14 @@ defined('MOODLE_INTERNAL') || die();
  *          [string] A class to use as the data loader for this definition.
  *          Any class used here must inherit the cache_data_loader interface.
  *     + datasourcefile
- *          [string] Suplements the above setting indicated the file containing the class to be used. This file is included when
+ *          [string] Supplements the above setting indicating the file containing the class to be used. This file is included when
  *          required.
- *     + persistent
- *          [bool] This setting does two important things. First it tells the cache API to only instantiate the cache structure for
- *          this definition once, further requests will be given the original instance.
- *          Second the cache loader will keep an array of the items set and retrieved to the cache during the request.
- *          This has several advantages including better performance without needing to start passing the cache instance between
- *          function calls, the downside is that the cache instance + the items used stay within memory.
- *          Consider using this setting when you know that there are going to be many calls to the cache for the same information
- *          or when you are converting existing code to the cache and need to access the cache within functions but don't want
- *          to add it as an argument to the function.
- *     + persistentmaxsize
- *          [int] This supplements the above setting by limiting the number of items in the caches persistent array of items.
+ *     + staticacceleration
+ *          The cache loader will keep an array of the items set and retrieved to the cache during the request.
+ *          Consider using this setting when you know that there are going to be many calls to the cache for the same information.
+ *          Requests for data in this array will be ultra fast, but it will cost memory.
+ *     + staticaccelerationsize
+ *          [int] This supplements the above setting by limiting the number of items in the static acceleration array.
  *          Tweaking this setting lower will allow you to minimise the memory implications above while hopefully still managing to
  *          offset calls to the cache store.
  *     + ttl
@@ -253,16 +248,16 @@ class cache_definition {
     protected $datasourceaggregate = null;
 
     /**
-     * Set to true if the definitions cache should be persistent
+     * Set to true if the cache should hold onto items passing through it to speed up subsequent requests.
      * @var bool
      */
-    protected $persistent = false;
+    protected $staticacceleration = false;
 
     /**
-     * The persistent item array max size.
+     * The maximum number of items that static acceleration cache should hold onto.
      * @var int
      */
-    protected $persistentmaxsize = false;
+    protected $staticaccelerationsize = false;
 
     /**
      * The TTL for data in this cache. Please don't use this, instead use event driven invalidation.
@@ -286,7 +281,7 @@ class cache_definition {
      * An array of identifiers provided to this cache when it was initialised.
      * @var array
      */
-    protected $identifiers = array();
+    protected $identifiers = null;
 
     /**
      * Key prefix for use with single key cache stores
@@ -363,8 +358,8 @@ class cache_definition {
         $overrideclassfile = null;
         $datasource = null;
         $datasourcefile = null;
-        $persistent = false;
-        $persistentmaxsize = false;
+        $staticacceleration = false;
+        $staticaccelerationsize = false;
         $ttl = 0;
         $mappingsonly = false;
         $invalidationevents = array();
@@ -419,10 +414,18 @@ class cache_definition {
         }
 
         if (array_key_exists('persistent', $definition)) {
-            $persistent = (bool)$definition['persistent'];
+            // Ahhh this is the legacy persistent option.
+            $staticacceleration = (bool)$definition['persistent'];
+        }
+        if (array_key_exists('staticacceleration', $definition)) {
+            $staticacceleration = (bool)$definition['staticacceleration'];
         }
         if (array_key_exists('persistentmaxsize', $definition)) {
-            $persistentmaxsize = (int)$definition['persistentmaxsize'];
+            // Ahhh this is the legacy persistentmaxsize option.
+            $staticaccelerationsize = (int)$definition['persistentmaxsize'];
+        }
+        if (array_key_exists('staticaccelerationsize', $definition)) {
+            $staticaccelerationsize = (int)$definition['staticaccelerationsize'];
         }
         if (array_key_exists('ttl', $definition)) {
             $ttl = (int)$definition['ttl'];
@@ -518,8 +521,8 @@ class cache_definition {
         $cachedefinition->datasource = $datasource;
         $cachedefinition->datasourcefile = $datasourcefile;
         $cachedefinition->datasourceaggregate = $datasourceaggregate;
-        $cachedefinition->persistent = $persistent;
-        $cachedefinition->persistentmaxsize = $persistentmaxsize;
+        $cachedefinition->staticacceleration = $staticacceleration;
+        $cachedefinition->staticaccelerationsize = $staticaccelerationsize;
         $cachedefinition->ttl = $ttl;
         $cachedefinition->mappingsonly = $mappingsonly;
         $cachedefinition->invalidationevents = $invalidationevents;
@@ -543,7 +546,8 @@ class cache_definition {
      *   - simplekeys : Set to true if the keys you will use are a-zA-Z0-9_
      *   - simpledata : Set to true if the type of the data you are going to store is scalar, or an array of scalar vars
      *   - overrideclass : The class to use as the loader.
-     *   - persistent : If set to true the cache will persist construction requests.
+     *   - staticacceleration : If set to true the cache will hold onto data passing through it.
+     *   - staticaccelerationsize : Set it to an int to limit the size of the staticacceleration cache.
      * @return cache_application|cache_session|cache_request
      */
     public static function load_adhoc($mode, $component, $area, array $options = array()) {
@@ -560,7 +564,14 @@ class cache_definition {
             $definition['simpledata'] = $options['simpledata'];
         }
         if (!empty($options['persistent'])) {
-            $definition['persistent'] = $options['persistent'];
+            // Ahhh this is the legacy persistent option.
+            $definition['staticacceleration'] = (bool)$options['persistent'];
+        }
+        if (!empty($options['staticacceleration'])) {
+            $definition['staticacceleration'] = (bool)$options['staticacceleration'];
+        }
+        if (!empty($options['staticaccelerationsize'])) {
+            $definition['staticaccelerationsize'] = (int)$options['staticaccelerationsize'];
         }
         if (!empty($options['overrideclass'])) {
             $definition['overrideclass'] = $options['overrideclass'];
@@ -643,6 +654,9 @@ class cache_definition {
      * @return array
      */
     public function get_identifiers() {
+        if (!isset($this->identifiers)) {
+            return array();
+        }
         return $this->identifiers;
     }
 
@@ -755,11 +769,22 @@ class cache_definition {
      * @throws coding_exception
      */
     public function set_identifiers(array $identifiers = array()) {
+        // If we are setting the exact same identifiers then just return as nothing really changed.
+        // We don't care about order as cache::make will use the same definition order all the time.
+        if ($identifiers === $this->identifiers) {
+            return;
+        }
+
         foreach ($this->requireidentifiers as $identifier) {
             if (!array_key_exists($identifier, $identifiers)) {
                 throw new coding_exception('Identifier required for cache has not been provided: '.$identifier);
             }
         }
+
+        if ($this->identifiers === null) {
+            // Initialize identifiers if they have not been.
+            $this->identifiers = array();
+        }
         foreach ($identifiers as $name => $value) {
             $this->identifiers[$name] = (string)$value;
         }
@@ -788,18 +813,53 @@ class cache_definition {
 
     /**
      * Returns true if this definitions cache should be made persistent.
+     *
+     * Please call {@link cache_definition::use_static_acceleration()} instead.
+     *
+     * @deprecated since 2.5.3
      * @return bool
      */
     public function should_be_persistent() {
-        return $this->persistent || $this->mode === cache_store::MODE_SESSION;
+        debugging('Please upgrade your code to use cache_definition::use_static_acceleration', DEBUG_DEVELOPER);
+        return $this->use_static_acceleration();
     }
 
     /**
-     * Returns the max size for the persistent item array in the cache.
+     * Returns true if we should hold onto the data flowing through the cache.
+     *
+     * If set to true data flowing through the cache will be stored in a static variable
+     * to make subsequent requests for the data much faster.
+     *
+     * @return bool
+     */
+    public function use_static_acceleration() {
+        if ($this->mode === cache_store::MODE_REQUEST) {
+            // Request caches should never use static acceleration - it just doesn't make sense.
+            return false;
+        }
+        return $this->staticacceleration;
+    }
+
+    /**
+     * Returns the max size for the static acceleration array.
+     *
+     * Please call {@link cache_definition::get_static_acceleration_size()} instead.
+     *
+     * @see cache_definition::get_static_acceleration_size()
+     * @deprecated since 2.5.3
      * @return int
      */
     public function get_persistent_max_size() {
-        return $this->persistentmaxsize;
+        debugging('Please upgrade your code to call cache_definition::get_static_acceleration_size', DEBUG_DEVELOPER);
+        return $this->get_static_acceleration_size();
+    }
+
+    /**
+     * Returns the max size for the static acceleration array.
+     * @return int
+     */
+    public function get_static_acceleration_size() {
+        return $this->staticaccelerationsize;
     }
 
     /**
@@ -846,7 +906,7 @@ class cache_definition {
                 'area' => $this->area,
                 'siteidentifier' => $this->get_cache_identifier()
             );
-            if (!empty($this->identifiers)) {
+            if (isset($this->identifiers) && !empty($this->identifiers)) {
                 $identifiers = array();
                 foreach ($this->identifiers as $key => $value) {
                     $identifiers[] = htmlentities($key, ENT_QUOTES, 'UTF-8').'='.htmlentities($value, ENT_QUOTES, 'UTF-8');
@@ -916,4 +976,31 @@ class cache_definition {
     public function has_required_identifiers() {
         return (count($this->requireidentifiers) > 0);
     }
-}
\ No newline at end of file
+
+    /**
+     * Returns the possible sharing options that can be used with this defintion.
+     *
+     * @return int
+     */
+    public function get_sharing_options() {
+        return $this->sharingoptions;
+    }
+
+    /**
+     * Returns the user entered sharing key for this definition.
+     *
+     * @return string
+     */
+    public function get_user_input_sharing_key() {
+        return $this->userinputsharingkey;
+    }
+
+    /**
+     * Returns the user selected sharing option for this definition.
+     *
+     * @return int
+     */
+    public function get_selected_sharing_option() {
+        return $this->selectedsharingoption;
+    }
+}
