@@ -1,22 +1,34 @@
-<?php // $Id: export_execute.php,v 1.2.4.1 2007/06/19 17:53:14 stronk7 Exp $
+<?php
 
 require_once('../config.php');
 //require_once($CFG->dirroot.'/course/lib.php');
 require_once($CFG->dirroot.'/calendar/lib.php');
 require_once($CFG->libdir.'/bennu/bennu.inc.php');
 
-$username = required_param('username', PARAM_TEXT);
+$userid = optional_param('userid', 0, PARAM_INT);
+$username = optional_param('username', '', PARAM_TEXT);
 $authtoken = required_param('authtoken', PARAM_ALPHANUM);
+$generateurl = optional_param('generateurl', '', PARAM_TEXT);
+
+if (empty($CFG->enablecalendarexport)) {
+    die('no export');
+}
 
 //Fetch user information
-if (!$user = get_complete_user_data('username', $username)) {
-   //No such user
-   die("No such user '$username'");
+$checkuserid = !empty($userid) && $user = $DB->get_record('user', array('id' => $userid), 'id,password');
+//allowing for fallback check of old url - MDL-27542
+$checkusername = !empty($username) && $user = $DB->get_record('user', array('username' => $username), 'id,password');
+if (!$checkuserid && !$checkusername) {
+    //No such user
+    die('Invalid authentication');
 }
 
 //Check authentication token
-if ($authtoken != sha1($username . $user->password)) {
-    die('Invalid authentication token');
+$authuserid = !empty($userid) && $authtoken == sha1($userid . $user->password . $CFG->calendar_exportsalt);
+//allowing for fallback check of old url - MDL-27542
+$authusername = !empty($username) && $authtoken == sha1($username . $user->password . $CFG->calendar_exportsalt);
+if (!$authuserid && !$authusername) {
+    die('Invalid authentication');
 }
 
 $what = optional_param('preset_what', 'all', PARAM_ALPHA);
@@ -25,22 +37,46 @@ $time = optional_param('preset_time', 'weeknow', PARAM_ALPHA);
 $now = usergetdate(time());
 // Let's see if we have sufficient and correct data
 $allowed_what = array('all', 'courses');
-$allowed_time = array('weeknow', 'weeknext', 'monthnow', 'monthnext', 'recentupcoming');
+$allowed_time = array('weeknow', 'weeknext', 'monthnow', 'monthnext', 'recentupcoming', 'custom');
+
+if (!empty($generateurl)) {
+    $authtoken = sha1($user->id . $user->password . $CFG->calendar_exportsalt);
+    $params = array();
+    $params['preset_what'] = $what;
+    $params['preset_time'] = $time;
+    $params['userid'] = $userid;
+    $params['authtoken'] = $authtoken;
+    $params['generateurl'] = true;
+
+    $link = new moodle_url('/calendar/export.php', $params);
+    redirect($link->out());
+    die;
+}
 
 if(!empty($what) && !empty($time)) {
     if(in_array($what, $allowed_what) && in_array($time, $allowed_time)) {
-        $courses = get_my_courses($user->id);
-        
-        $include_user = ($what == 'all');
-        if ($include_user) {
-            //Also include site (global) events
+        $courses = enrol_get_users_courses($user->id, true, 'id, visible, shortname');
+
+        if ($what == 'all') {
+            $users = $user->id;
+            $groups = array();
+            foreach ($courses as $course) {
+                $course_groups = groups_get_all_groups($course->id, $user->id);
+                $groups = array_merge($groups, array_keys($course_groups));
+            }
+            if (empty($groups)) {
+                $groups = false;
+            }
             $courses[SITEID] = new stdClass;
             $courses[SITEID]->shortname = get_string('globalevents', 'calendar');
+        } else {
+            $users = false;
+            $groups = false;
         }
 
         switch($time) {
             case 'weeknow':
-                $startweekday  = get_user_preferences('calendar_startwday', CALENDAR_STARTING_WEEKDAY);
+                $startweekday  = get_user_preferences('calendar_startwday', calendar_get_starting_weekday());
                 $startmonthday = find_day_in_month($now['mday'] - 6, $startweekday, $now['mon'], $now['year']);
                 $startmonth    = $now['mon'];
                 $startyear     = $now['year'];
@@ -59,7 +95,7 @@ if(!empty($what) && !empty($time)) {
                 $timeend = make_timestamp($endyear, $endmonth, $endmonthday) - 1;
             break;
             case 'weeknext':
-                $startweekday  = get_user_preferences('calendar_startwday', CALENDAR_STARTING_WEEKDAY);
+                $startweekday  = get_user_preferences('calendar_startwday', calendar_get_starting_weekday());
                 $startmonthday = find_day_in_month($now['mday'] + 1, $startweekday, $now['mon'], $now['year']);
                 $startmonth    = $now['mon'];
                 $startyear     = $now['year'];
@@ -91,6 +127,11 @@ if(!empty($what) && !empty($time)) {
                 $timestart = time() - 432000;
                 $timeend = time() + 5184000;
             break;
+            case 'custom':
+                // Events based on custom date range.
+                $timestart = time() - $CFG->calendar_exportlookback * DAYSECS;
+                $timeend = time() + $CFG->calendar_exportlookahead * DAYSECS;
+            break;
         }
     }
     else {
@@ -99,25 +140,24 @@ if(!empty($what) && !empty($time)) {
         die();
     }
 }
-
-$whereclause = calendar_sql_where($timestart, $timeend, $include_user ? array($user->id) : false, false, array_keys($courses), false);
-if($whereclause === false) {
-    $events = array();
-}
-else {
-    $events = get_records_select('event', $whereclause, 'timestart');
-}
-
-if ($events === false) {
-    $events = array();
-}
+$events = calendar_get_events($timestart, $timeend, $users, $groups, array_keys($courses), false);
 
 $ical = new iCalendar;
 $ical->add_property('method', 'PUBLISH');
 foreach($events as $event) {
+   if (!empty($event->modulename)) {
+        $cm = get_coursemodule_from_instance($event->modulename, $event->instance);
+        if (!groups_course_module_visible($cm)) {
+            continue;
+        }
+    }
+    $hostaddress = str_replace('http://', '', $CFG->wwwroot);
+    $hostaddress = str_replace('https://', '', $hostaddress);
+
     $ev = new iCalendar_event;
+    $ev->add_property('uid', $event->id.'@'.$hostaddress);
     $ev->add_property('summary', $event->name);
-    $ev->add_property('description', $event->description);
+    $ev->add_property('description', clean_param($event->description, PARAM_NOTAGS));
     $ev->add_property('class', 'PUBLIC'); // PUBLIC / PRIVATE / CONFIDENTIAL
     $ev->add_property('last-modified', Bennu::timestamp_to_datetime($event->timemodified));
     $ev->add_property('dtstamp', Bennu::timestamp_to_datetime()); // now
@@ -127,7 +167,8 @@ foreach($events as $event) {
         $ev->add_property('dtend', Bennu::timestamp_to_datetime($event->timestart + $event->timeduration));
     }
     if ($event->courseid != 0) {
-        $ev->add_property('categories', $courses[$event->courseid]->shortname);
+        $coursecontext = context_course::instance($event->courseid);
+        $ev->add_property('categories', format_string($courses[$event->courseid]->shortname, true, array('context' => $coursecontext)));
     }
     $ical->add_component($ev);
 }
@@ -138,11 +179,6 @@ if(empty($serialized)) {
     die('bad serialization');
 }
 
-//IE compatibility HACK!
-if(ini_get('zlib.output_compression')) {
-    ini_set('zlib.output_compression', 'Off');
-}
-
 $filename = 'icalexport.ics';
 
 header('Last-Modified: '. gmdate('D, d M Y H:i:s', time()) .' GMT');
@@ -152,8 +188,6 @@ header('Pragma: no-cache');
 header('Accept-Ranges: none'); // Comment out if PDFs do not work...
 header('Content-disposition: attachment; filename='.$filename);
 header('Content-length: '.strlen($serialized));
-header('Content-type: text/calendar');
+header('Content-type: text/calendar; charset=utf-8');
 
 echo $serialized;
-
-?>
