@@ -1,6 +1,6 @@
 <?php
 /* 
-V4.93 10 Oct 2006  (c) 2000-2006 John Lim (jlim#natsoft.com.my). All rights reserved.
+V5.18 3 Sep 2012  (c) 2000-2012 John Lim (jlim#natsoft.com). All rights reserved.
 Released under both BSD license and Lesser GPL library license. 
 Whenever there is any discrepancy between the two licenses, 
 the BSD license will take precedence. See License.txt. 
@@ -26,18 +26,18 @@ class  ADODB_ado_access extends ADODB_ado {
 	var $fmtTimeStamp = "#Y-m-d h:i:sA#";// note no comma
 	var $sysDate = "FORMAT(NOW,'yyyy-mm-dd')";
 	var $sysTimeStamp = 'NOW';
-	var $hasTransactions = false;
+	var $upperCase = 'ucase';
 	
 	function ADODB_ado_access()
 	{
 		$this->ADODB_ado();
 	}
 	
-	function BeginTrans() { return false;}
+	/*function BeginTrans() { return false;}
 	
 	function CommitTrans() { return false;}
 	
-	function RollbackTrans() { return false;}
+	function RollbackTrans() { return false;}*/
 
 }
 
