@@ -1,6 +1,6 @@
 <?php
 /* 
-V4.51 29 July 2004  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights reserved.
+V5.18 3 Sep 2012  (c) 2000-2012 John Lim (jlim#natsoft.com). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence. See License.txt. 
@@ -63,7 +63,7 @@ class perf_informix extends adodb_perf{
 	
 	function perf_informix(&$conn)
 	{
-		$this->conn =& $conn;
+		$this->conn = $conn;
 	}
 
 }
