@@ -1,6 +1,6 @@
 <?php
 /* 
-V4.93 10 Oct 2006  (c) 2000-2006 John Lim (jlim#natsoft.com.my). All rights reserved.
+V5.18 3 Sep 2012  (c) 2000-2012 John Lim (jlim#natsoft.com). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence. See License.txt. 
@@ -83,7 +83,7 @@ class perf_mysql extends adodb_perf{
 	
 	function perf_mysql(&$conn)
 	{
-		$this->conn =& $conn;
+		$this->conn = $conn;
 	}
 	
 	function Explain($sql,$partial=false)
@@ -251,7 +251,7 @@ class perf_mysql extends adodb_perf{
 		$ADODB_FETCH_MODE = ADODB_FETCH_NUM;
 		if ($this->conn->fetchMode !== false) $savem = $this->conn->SetFetchMode(false);
 		
-		$rs = $this->conn->Execute('show innodb status');
+		$rs = $this->conn->Execute('show engine innodb status');
 		
 		if (isset($savem)) $this->conn->SetFetchMode($savem);
 		$ADODB_FETCH_MODE = $save;
