@@ -104,8 +104,13 @@ M.form_filemanager.init = function(Y, options) {
             }
             // initialize 'select file' panel
             this.selectnode = Y.Node.createWithFilesSkin(M.form_filemanager.templates.fileselectlayout);
+            this.selectnode.setAttribute('aria-live', 'assertive');
+            this.selectnode.setAttribute('role', 'dialog');
             this.selectnode.generateID();
+
+            var labelid = 'fm-dialog-label_'+ this.selectnode.get('id');
             this.selectui = new Y.Panel({
+                headerContent: '<span id="' + labelid +'">' + M.str.moodle.edit + '</span>',
                 srcNode      : this.selectnode,
                 zIndex       : 7600,
                 centered     : true,
@@ -114,6 +119,7 @@ M.form_filemanager.init = function(Y, options) {
                 render       : true
             });
             this.selectui.plug(Y.Plugin.Drag,{handles:['#'+this.selectnode.get('id')+' .yui3-widget-hd']});
+            Y.one('#'+this.selectnode.get('id')).setAttribute('aria-labelledby', labelid);
             this.selectui.hide();
             this.setup_select_file();
             // setup buttons onclick events
@@ -401,6 +407,8 @@ M.form_filemanager.init = function(Y, options) {
                         }
                         e.currentTarget.addClass('checked')
                         this.render();
+                        this.filemanager.one('.fp-content').setAttribute('tabIndex', '0');
+                        this.filemanager.one('.fp-content').focus();
                     }
                 }, this);
         },
@@ -1011,8 +1019,17 @@ M.form_filemanager.init = function(Y, options) {
                     }
                 }, false);
             }
+            // update dialog header
+            var nodename = node.fullname;
+            // Limit the string length so it fits nicely on mobile devices
+            var namelength = 50;
+            if (nodename.length > namelength) {
+                nodename = nodename.substring(0, namelength) + '...';
+            }
+            Y.one('#fm-dialog-label_'+selectnode.get('id')).setContent(Y.Escape.html(M.str.moodle.edit+' '+nodename));
             // show panel
             this.selectui.show();
+            Y.one('#'+selectnode.get('id')).focus();
         },
         render: function() {
             this.print_path();
