@@ -1313,10 +1313,10 @@ function openpopup(event, args) {
         args.name = '_blank';
     } else if (args.name.match(nameregex)) {
         // Cleans window name because IE does not support funky ones.
-        args.name = args.name.replace(nameregex, '_');
         if (M.cfg.developerdebug) {
-            alert('DEVELOPER NOTICE: Invalid \'name\' passed to openpopup()');
+            alert('DEVELOPER NOTICE: Invalid \'name\' passed to openpopup(): ' + args.name);
         }
+        args.name = args.name.replace(nameregex, '_');
     }
 
     var fullurl = args.url;
