@@ -1,18 +1,44 @@
-<?php //$Id: olson.php,v 1.24 2006/08/22 20:10:54 stronk7 Exp $
+<?php
 
-/***
- *** olson_to_timezones ($filename)
- ***
- *** Parses the olson files for Zones and DST rules.
- *** It updates the Moodle database with the Zones/DST rules
- ***
- *** Returns true/false
- ***
+// This file is part of Moodle - http://moodle.org/
+//
+// Moodle is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Moodle is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
+
+/**
+ * @package   moodlecore
+ * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
+ * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ */
+
+/**
+ * olson_to_timezones ($filename)
+ *
+ * Parses the olson files for Zones and DST rules.
+ * It updates the Moodle database with the Zones/DST rules
+ *
+ * @param string $filename
+ * @return bool true/false
+ *
  */
 function olson_to_timezones ($filename) {
 
-    $zones = olson_simple_zone_parser($filename);
-    $rules = olson_simple_rule_parser($filename);
+    // Look for zone and rule information up to 10 years in the future.
+    $maxyear = localtime(time(), true);
+    $maxyear = $maxyear['tm_year'] + 1900 + 10;
+
+    $zones = olson_simple_zone_parser($filename, $maxyear);
+    $rules = olson_simple_rule_parser($filename, $maxyear);
 
     $mdl_zones = array();
 
@@ -20,30 +46,28 @@ function olson_to_timezones ($filename) {
      *** To translate the combined Zone & Rule changes
      *** in the Olson files to the Moodle single ruleset
      *** format, we need to trasverse every year and see
-     *** if either the Zone or the relevant Rule has a 
+     *** if either the Zone or the relevant Rule has a
      *** change. It's yuck but it yields a rationalized
      *** set of data, which is arguably simpler.
      ***
      *** Also note that I am starting at the epoch (1970)
      *** because I don't think we'll see many events scheduled
-     *** before that, anyway. 
+     *** before that, anyway.
      ***
      **/
-    $maxyear = localtime(time(), true);
-    $maxyear = $maxyear['tm_year'] + 1900 + 10;
 
     foreach ($zones as $zname => $zbyyear) { // loop over zones
         /**
          *** Loop over years, only adding a rule when zone or rule
          *** have changed. All loops preserver the last seen vars
          *** until there's an explicit decision to delete them
-         *** 
-         **/ 
+         ***
+         **/
 
         // clean the slate for a new zone
         $zone = NULL;
         $rule = NULL;
-        
+
         //
         // Find the pre 1970 zone rule entries
         //
@@ -57,16 +81,16 @@ function olson_to_timezones ($filename) {
         if (!empty($zone['rule']) && array_key_exists($zone['rule'], $rules)) {
             $rule = NULL;
             for ($y = 1970 ; $y > 0 ; $y--) {
-                if (array_key_exists((string)$y, $rules[$zone['rule']] )) { // we have a rule entry for the year                    
+                if (array_key_exists((string)$y, $rules[$zone['rule']] )) { // we have a rule entry for the year
                     $rule  =  $rules[$zone['rule']][$y];
                     //print_object("Rule $rule[name] pre1970 is $y\n");
                     break; // Perl's last -- get outta here
                 }
-                
-            }  
+
+            }
             if (empty($rule)) {
-                // Colombia and a few others refer to rules before they exist 
-                // Perhaps we should comment out this warning... 
+                // Colombia and a few others refer to rules before they exist
+                // Perhaps we should comment out this warning...
                 // trigger_error("Cannot find rule in $zone[rule] <= 1970");
                 $rule  = array();
             }
@@ -74,11 +98,11 @@ function olson_to_timezones ($filename) {
             // no DST this year!
             $rule  = array();
         }
-        
-        // Prepare to insert the base 1970 zone+rule        
+
+        // Prepare to insert the base 1970 zone+rule
         if (!empty($rule) && array_key_exists($zone['rule'], $rules)) {
             // merge the two arrays into the moodle rule
-            unset($rule['name']); // warning: $rule must NOT be a reference! 
+            unset($rule['name']); // warning: $rule must NOT be a reference!
             unset($rule['year']);
             $mdl_tz = array_merge($zone, $rule);
 
@@ -90,7 +114,7 @@ function olson_to_timezones ($filename) {
             $mdl_tz = $zone;
             // TODO: Add other default values here!
             $mdl_tz['dstoff'] = 0;
-        }        
+        }
 
         // Fix the from year to 1970
         $mdl_tz['year'] = 1970;
@@ -103,7 +127,7 @@ function olson_to_timezones ($filename) {
 
         ///
         /// 1971 onwards
-        /// 
+        ///
         for ($y = 1971; $y < $maxyear ; $y++) {
             $changed = false;
             ///
@@ -116,7 +140,7 @@ function olson_to_timezones ($filename) {
                 $changed = true;
                 $zone    = $zbyyear[(string)$y];
             }
-            if (!empty($zone['rule']) && array_key_exists($zone['rule'], $rules)) {                
+            if (!empty($zone['rule']) && array_key_exists($zone['rule'], $rules)) {
                 if (array_key_exists((string)$y, $rules[$zone['rule']])) {
                     $changed = true;
                     $rule    = $rules[$zone['rule']][(string)$y];
@@ -129,7 +153,7 @@ function olson_to_timezones ($filename) {
                 //print_object("CHANGE YEAR $y Zone $zone[name] Rule $zone[rule]\n");
                 if (!empty($rule)) {
                     // merge the two arrays into the moodle rule
-                    unset($rule['name']); 
+                    unset($rule['name']);
                     unset($rule['year']);
                     $mdl_tz = array_merge($zone, $rule);
 
@@ -142,7 +166,7 @@ function olson_to_timezones ($filename) {
                 } else {
                     // just a simple zone
                     $mdl_tz = $zone;
-                } 
+                }
 
 /*
 if(isset($mdl_tz['dst_time']) && !strpos($mdl_tz['dst_time'], ':') || isset($mdl_tz['std_time']) &&  !strpos($mdl_tz['std_time'], ':')) {
@@ -158,11 +182,11 @@ if(isset($mdl_tz['dst_time']) && !strpos($mdl_tz['dst_time'], ':') || isset($mdl
                     $mdl_zones[] = $lasttimezone = $mdl_tz;
                 }
             }
-        } 
-        
+        }
+
     }
 
-    /* 
+    /*
     if (function_exists('memory_get_usage')) {
         trigger_error("We are consuming this much memory: " . get_memory_usage());
     }
@@ -171,34 +195,55 @@ if(isset($mdl_tz['dst_time']) && !strpos($mdl_tz['dst_time'], ':') || isset($mdl
 /// Since Moodle 1.7, rule is tzrule in DB (reserved words problem), so change it here
 /// after everything is calculated to be properly loaded to the timezone table.
 /// Pre 1.7 users won't have the old rule if updating this from moodle.org but it
-/// seems that such field isn't used at all by the rest of Moodle (at least I haven't 
+/// seems that such field isn't used at all by the rest of Moodle (at least I haven't
 /// found any use when looking for it).
 
     foreach($mdl_zones as $key=>$mdl_zone) {
         $mdl_zones[$key]['tzrule'] = $mdl_zones[$key]['rule'];
     }
-    
+
     return $mdl_zones;
 }
 
 
-/***
- *** olson_simple_rule_parser($filename)
- ***
- *** Parses the olson files for DST rules.
- *** It's a simple implementation that simplifies some fields
- ***
- *** Returns a multidimensional array, or false on error
- ***
+/**
+ * olson_simple_rule_parser($filename)
+ *
+ * Parses the olson files for DST rules.
+ * It's a simple implementation that simplifies some fields
+ *
+ * @return array a multidimensional array, or false on error
+ *
  */
-function olson_simple_rule_parser ($filename) {
+function olson_simple_rule_parser($filename, $maxyear) {
 
-    $file = fopen($filename, 'r', 0); 
+    $file = fopen($filename, 'r', 0);
 
     if (empty($file)) {
         return false;
     }
-    
+
+    while ($line = fgets($file)) {
+        // only pay attention to rules lines
+        if(!preg_match('/^Rule\s/', $line)){
+            continue;
+        }
+        $line = preg_replace('/\n$/', '',$line); // chomp
+        $rule = preg_split('/\s+/', $line);
+        list($discard,
+             $name,
+             $from,
+             $to,
+             $type,
+             $in,
+             $on,
+             $at,
+             $save,
+             $letter) = $rule;
+    }
+
+    fseek($file, 0);
+
     $rules = array();
     while ($line = fgets($file)) {
         // only pay attention to rules lines
@@ -224,7 +269,7 @@ function olson_simple_rule_parser ($filename) {
             $to = $from;
         }
         else if($to == 'max') {
-            $to = date('Y');
+            $to = $maxyear;
         }
 
         for($i = $from; $i <= $to; ++$i) {
@@ -235,11 +280,11 @@ function olson_simple_rule_parser ($filename) {
 
     fclose($file);
 
-    $months = array('jan' =>  1, 'feb' =>  2, 
-                    'mar' =>  3, 'apr' =>  4, 
+    $months = array('jan' =>  1, 'feb' =>  2,
+                    'mar' =>  3, 'apr' =>  4,
                     'may' =>  5, 'jun' =>  6,
-                    'jul' =>  7, 'aug' =>  8, 
-                    'sep' =>  9, 'oct' => 10, 
+                    'jul' =>  7, 'aug' =>  8,
+                    'sep' =>  9, 'oct' => 10,
                     'nov' => 11, 'dec' => 12);
 
 
@@ -281,24 +326,24 @@ function olson_simple_rule_parser ($filename) {
                  $at,
                  $save,
                  $letter) = $rulesthisyear['set'];
-    
+
             $moodle_rule = array();
-    
+
             // $save is sometimes just minutes
             // and othertimes HH:MM -- only
             // parse if relevant
-            if (!preg_match('/^\d+$/', $save)) {                 
+            if (!preg_match('/^\d+$/', $save)) {
                 list($hours, $mins) = explode(':', $save);
                 $save = $hours * 60 + $mins;
             }
 
             // we'll parse $at later
-            // $at = olson_parse_at($at); 
+            // $at = olson_parse_at($at);
             $in = strtolower($in);
             if(!isset($months[$in])) {
                 trigger_error('Unknown month: '.$in);
             }
-    
+
             $moodle_rule['name']   = $name;
             $moodle_rule['year']   = $year;
             $moodle_rule['dstoff'] = $save; // time offset
@@ -311,7 +356,7 @@ function olson_simple_rule_parser ($filename) {
             $moodle_rule['dst_startday']  = $on['startday'];
             $moodle_rule['dst_weekday']   = $on['weekday'];
             $moodle_rule['dst_skipweeks'] = $on['skipweeks'];
-            
+
             // and now the "deactivate" data
             list($discard,
                  $name,
@@ -323,7 +368,7 @@ function olson_simple_rule_parser ($filename) {
                  $at,
                  $save,
                  $letter) = $rulesthisyear['reset'];
-    
+
             // we'll parse $at later
             // $at = olson_parse_at($at);
             $in = strtolower($in);
@@ -333,13 +378,13 @@ function olson_simple_rule_parser ($filename) {
 
             $moodle_rule['std_month'] = $months[$in]; // the month
             $moodle_rule['std_time']  = $at; // the time
-    
+
             // Encode index and day as per Moodle's specs
             $on = olson_parse_on($on);
             $moodle_rule['std_startday']  = $on['startday'];
             $moodle_rule['std_weekday']   = $on['weekday'];
             $moodle_rule['std_skipweeks'] = $on['skipweeks'];
-                
+
             $moodle_rules[$moodle_rule['name']][$moodle_rule['year']] = $moodle_rule;
             //print_object($moodle_rule);
 
@@ -350,7 +395,7 @@ function olson_simple_rule_parser ($filename) {
         // then we have to deal with closing the last rule
         //trigger_error("Rule $name ending to $to");
         if (!empty($to) && $to !== 'max') {
-            // We can handle two cases for TO: 
+            // We can handle two cases for TO:
             // a year, or "only"
             $reset_rule = $moodle_rule;
             $reset_rule['dstoff'] = '00';
@@ -371,22 +416,22 @@ function olson_simple_rule_parser ($filename) {
     return $moodle_rules;
 }
 
-/***
- *** olson_simple_zone_parser($filename)
- ***
- *** Parses the olson files for zone info
- ***
- *** Returns a multidimensional array, or false on error
- ***
+/**
+ * olson_simple_zone_parser($filename)
+ *
+ * Parses the olson files for zone info
+ *
+ * @return array a multidimensional array, or false on error
+ *
  */
-function olson_simple_zone_parser ($filename) {
+function olson_simple_zone_parser($filename, $maxyear) {
 
-    $file = fopen($filename, 'r', 0); 
+    $file = fopen($filename, 'r', 0);
 
     if (empty($file)) {
         return false;
     }
-    
+
     $zones = array();
     $lastzone = NULL;
 
@@ -417,7 +462,7 @@ function olson_simple_zone_parser ($filename) {
          ***
          *** We are transforming "until" fields into "from" fields
          *** which make more sense from the Moodle perspective, so
-         *** each initial Zone entry is "from" the year 0, and for the 
+         *** each initial Zone entry is "from" the year 0, and for the
          *** continuation lines, we shift the "until" from the previous field
          *** into this line's "from".
          ***
@@ -425,7 +470,7 @@ function olson_simple_zone_parser ($filename) {
          *** I have no idea of how to create a DST rule out of that
          *** (what are the start/end times?)
          ***
-         *** We remove "until" from the data we keep, but preserve 
+         *** We remove "until" from the data we keep, but preserve
          *** it in $lastzone.
          */
         if (preg_match('/^Zone/', $line)) { // a new zone
@@ -439,15 +484,15 @@ function olson_simple_zone_parser ($filename) {
                   $discard // format
                   ) = $line;
             // the things we do to avoid warnings
-            if (!empty($line[5])) { 
+            if (!empty($line[5])) {
                 $zone['until'] = $line[5];
             }
             $zone['year'] = '0';
-            
+
             $zones[$zone['name']] = array();
 
-        } else if (!empty($lastzone) && preg_match('/^\s+/', $line)){ 
-            // looks like a credible continuation line  
+        } else if (!empty($lastzone) && preg_match('/^\s+/', $line)){
+            // looks like a credible continuation line
             $line = trim($line);
             $line = preg_split('/\s+/', $line);
             if (count($line) < 3) {
@@ -464,7 +509,7 @@ function olson_simple_zone_parser ($filename) {
                   $discard // format
                   ) = $line;
             // the things we do to avoid warnings
-            if (!empty($line[3])) { 
+            if (!empty($line[3])) {
                 $zone['until'] = $line[3];
             }
 
@@ -473,7 +518,7 @@ function olson_simple_zone_parser ($filename) {
             continue;
         }
 
-        // tidy up, we're done 
+        // tidy up, we're done
         // perhaps we should insert in the DB at this stage?
         $lastzone = $zone;
         unset($zone['until']);
@@ -481,32 +526,34 @@ function olson_simple_zone_parser ($filename) {
         if ($zone['rule'] === '-') { // cleanup empty rules
             $zone['rule'] = '';
         }
-        if (preg_match('/:/',$zone['rule'])) { 
+        if (preg_match('/:/',$zone['rule'])) {
             // we are not handling direct SAVE rules here
             // discard it
             $zone['rule'] = '';
         }
-        
+
         $zones[$zone['name']][(string)$zone['year']] = $zone;
     }
 
     return $zones;
 }
 
-/***
- *** olson_parse_offset($offset)
- ***
- *** parses time offsets from the GMTOFF and SAVE
- *** fields into +/-MINUTES 
+/**
+ * olson_parse_offset($offset)
+ *
+ * parses time offsets from the GMTOFF and SAVE
+ * fields into +/-MINUTES
+ *
+ * @return int
  */
 function olson_parse_offset ($offset) {
     $offset = trim($offset);
-    
+
     // perhaps it's just minutes
     if (preg_match('/^(-?)(\d*)$/', $offset)) {
         return intval($offset);
     }
-    // (-)hours:minutes(:seconds) 
+    // (-)hours:minutes(:seconds)
     if (preg_match('/^(-?)(\d*):(\d+)/', $offset, $matches)) {
         // we are happy to discard the seconds
         $sign    = $matches[1];
@@ -514,7 +561,7 @@ function olson_parse_offset ($offset) {
         $seconds = intval($matches[3]);
         $offset  = $sign . ($hours*60 + $seconds);
         return intval($offset);
-    } 
+    }
 
     trigger_error('Strange time format in olson_parse_offset() ' .$offset);
     return 0;
@@ -522,37 +569,37 @@ function olson_parse_offset ($offset) {
 }
 
 
-/***
- *** olson_parse_on_($on)
- ***
- *** see `man zic`. This function translates the following formats 
- *** 5        the fifth of the month
- *** lastSun  the last Sunday in the month
- *** lastMon  the last Monday in the month
- *** Sun>=8   first Sunday on or after the eighth
- *** Sun<=25  last Sunday on or before the 25th
- ***
- *** to a moodle friendly format. Returns an array with:
- ***
- *** startday: the day of the month that we start counting from.
- ***           if negative, it means we start from that day and
- ***           count backwards. since -1 would be meaningless,
- ***           it means "end of month and backwards".
- *** weekday:  the day of the week that we must find. we will
- ***           scan days from the startday until we find the
- ***           first such weekday. 0...6 = Sun...Sat.
- ***           -1 means that any day of the week will do,
- ***           effectively ending the search on startday.
- *** skipweeks:after finding our end day as outlined above,
- ***           skip this many weeks. this enables us to find
- ***           "the second sunday >= 10". usually will be 0.
+/**
+ * olson_parse_on_($on)
+ *
+ * see `man zic`. This function translates the following formats
+ * 5        the fifth of the month
+ * lastSun  the last Sunday in the month
+ * lastMon  the last Monday in the month
+ * Sun>=8   first Sunday on or after the eighth
+ * Sun<=25  last Sunday on or before the 25th
+ *
+ * to a moodle friendly format. Returns an array with:
+ *
+ * startday: the day of the month that we start counting from.
+ *           if negative, it means we start from that day and
+ *           count backwards. since -1 would be meaningless,
+ *           it means "end of month and backwards".
+ * weekday:  the day of the week that we must find. we will
+ *           scan days from the startday until we find the
+ *           first such weekday. 0...6 = Sun...Sat.
+ *           -1 means that any day of the week will do,
+ *           effectively ending the search on startday.
+ * skipweeks:after finding our end day as outlined above,
+ *           skip this many weeks. this enables us to find
+ *           "the second sunday >= 10". usually will be 0.
  */
 function olson_parse_on ($on) {
 
     $rule = array();
-    $days = array('sun' => 0, 'mon' => 1, 
-                  'tue' => 2, 'wed' => 3, 
-                  'thu' => 4, 'fri' => 5, 
+    $days = array('sun' => 0, 'mon' => 1,
+                  'tue' => 2, 'wed' => 3,
+                  'thu' => 4, 'fri' => 5,
                   'sat' => 6);
 
     if(is_numeric($on)) {
@@ -598,30 +645,30 @@ function olson_parse_on ($on) {
         else {
             trigger_error('unknown on '.$on);
         }
-    }    
+    }
     return $rule;
 }
 
 
-/***
- *** olson_parse_at($at, $set, $gmtoffset)
- ***
- *** see `man zic`. This function translates
- ***
- ***      2        time in hours
- ***      2:00     time in hours and minutes
- ***     15:00     24-hour format time (for times after noon)
- ***      1:28:14  time in hours, minutes, and seconds
- ***
- ***  Any of these forms may be followed by the letter w if the given
- ***  time is local "wall clock" time, s if the given time  is  local
- ***  "standard"  time, or u (or g or z) if the given time is univer-
- ***  sal time; in the absence of an indicator, wall  clock  time  is
- ***  assumed.
- ***
- *** returns a moodle friendly $at, in GMT, which is what Moodle wants
- ***
- *** 
+/**
+ * olson_parse_at($at, $set, $gmtoffset)
+ *
+ * see `man zic`. This function translates
+ *
+ *      2        time in hours
+ *      2:00     time in hours and minutes
+ *     15:00     24-hour format time (for times after noon)
+ *      1:28:14  time in hours, minutes, and seconds
+ *
+ *  Any of these forms may be followed by the letter w if the given
+ *  time is local "wall clock" time, s if the given time  is  local
+ *  "standard"  time, or u (or g or z) if the given time is univer-
+ *  sal time; in the absence of an indicator, wall  clock  time  is
+ *  assumed.
+ *
+ * @return string a moodle friendly $at, in GMT, which is what Moodle wants
+ *
+ *
  */
 function olson_parse_at ($at, $set = 'set', $gmtoffset) {
 
@@ -632,6 +679,7 @@ function olson_parse_at ($at, $set = 'set', $gmtoffset) {
         $at  = substr($at, 0, strlen($at)-1); // chop
     }
 
+    $at = (strpos($at, ':') === false) ? $at . ':0' : $at;
     list($hours, $mins) = explode(':', $at);
 
     // GMT -- return as is!
@@ -642,10 +690,10 @@ function olson_parse_at ($at, $set = 'set', $gmtoffset) {
     }
 
     // Wall clock
-    if (empty($sig) || $sig === 'w') { 
+    if (empty($sig) || $sig === 'w') {
         if ($set !== 'set'){ // wall clock is on DST, assume by 1hr
             $hours = $hours-1;
-        } 
+        }
         $sig = 's';
     }
 
@@ -660,6 +708,3 @@ function olson_parse_at ($at, $set = 'set', $gmtoffset) {
 
     trigger_error('unhandled case - AT flag is ' . $matches[0]);
 }
-
-
-?>
