@@ -435,7 +435,8 @@ class legacy_file_session extends session_stub {
         // Need to disable debugging since disk_free_space()
         // will fail on very large partitions (see MDL-19222)
         $freespace = @disk_free_space($CFG->dataroot.'/sessions');
-        if (!($freespace > 2048) and $freespace !== false) {
+        // MDL-43039: disk_free_space() returns null if disabled.
+        if (!($freespace > 2048) and ($freespace !== false) and ($freespace !== null)) {
             print_error('sessiondiskfull', 'error');
         }
         ini_set('session.save_path', $CFG->dataroot .'/sessions');
