@@ -663,49 +663,43 @@ class filter_delete_config_testcase extends advanced_testcase {
 }
 
 class filter_filter_set_applies_to_strings extends advanced_testcase {
-    protected $origcfgstringfilters;
-    protected $origcfgfilterall;
-
-    protected function setUp() {
-        global $DB, $CFG;
-        parent::setUp();
-
-        $DB->delete_records('filter_active', array());
-        $DB->delete_records('filter_config', array());
-        $this->resetAfterTest(false);
-
-        // Store original $CFG;
-        $this->origcfgstringfilters = $CFG->stringfilters;
-        $this->origcfgfilterall = $CFG->filterall;
-    }
-
-    protected function tearDown() {
-        global $CFG;
-        $CFG->stringfilters = $this->origcfgstringfilters;
-        $CFG->filterall = $this->origcfgfilterall;
-
-        parent::tearDown();
-    }
-
     public function test_set() {
         global $CFG;
+        $this->resetAfterTest();
+
+        $this->assertFileExists("$CFG->dirroot/filter/emailprotect"); // Any standard filter.
+        $this->assertFileExists("$CFG->dirroot/filter/tidy");         // Any standard filter.
+        $this->assertFileNotExists("$CFG->dirroot/filter/grgrggr");   // Any non-existent filter
+
         // Setup fixture.
-        $CFG->filterall = 0;
-        $CFG->stringfilters = '';
+        set_config('filterall', 0);
+        set_config('stringfilters', '');
         // Exercise SUT.
-        filter_set_applies_to_strings('name', true);
+        filter_set_applies_to_strings('tidy', true);
         // Validate.
-        $this->assertEquals('name', $CFG->stringfilters);
+        $this->assertEquals('tidy', $CFG->stringfilters);
+        $this->assertEquals(1, $CFG->filterall);
+
+        filter_set_applies_to_strings('grgrggr', true);
+        $this->assertEquals('tidy', $CFG->stringfilters);
+        $this->assertEquals(1, $CFG->filterall);
+
+        filter_set_applies_to_strings('emailprotect', true);
+        $this->assertEquals('tidy,emailprotect', $CFG->stringfilters);
         $this->assertEquals(1, $CFG->filterall);
     }
 
     public function test_unset_to_empty() {
         global $CFG;
+        $this->resetAfterTest();
+
+        $this->assertFileExists("$CFG->dirroot/filter/tidy"); // Any standard filter.
+
         // Setup fixture.
-        $CFG->filterall = 1;
-        $CFG->stringfilters = 'name';
+        set_config('filterall', 1);
+        set_config('stringfilters', 'tidy');
         // Exercise SUT.
-        filter_set_applies_to_strings('name', false);
+        filter_set_applies_to_strings('tidy', false);
         // Validate.
         $this->assertEquals('', $CFG->stringfilters);
         $this->assertEquals('', $CFG->filterall);
@@ -713,13 +707,38 @@ class filter_filter_set_applies_to_strings extends advanced_testcase {
 
     public function test_unset_multi() {
         global $CFG;
+        $this->resetAfterTest();
+
+        $this->assertFileExists("$CFG->dirroot/filter/emailprotect"); // Any standard filter.
+        $this->assertFileExists("$CFG->dirroot/filter/tidy");         // Any standard filter.
+        $this->assertFileExists("$CFG->dirroot/filter/multilang");    // Any standard filter.
+
         // Setup fixture.
-        $CFG->filterall = 1;
-        $CFG->stringfilters = 'name,other';
+        set_config('filterall', 1);
+        set_config('stringfilters', 'emailprotect,tidy,multilang');
         // Exercise SUT.
-        filter_set_applies_to_strings('name', false);
+        filter_set_applies_to_strings('tidy', false);
         // Validate.
-        $this->assertEquals('other', $CFG->stringfilters);
+        $this->assertEquals('emailprotect,multilang', $CFG->stringfilters);
         $this->assertEquals(1, $CFG->filterall);
     }
 }
+
+
+class filter_manager_testcase extends advanced_testcase {
+    public function test_filter_manager_instance() {
+        $this->resetAfterTest();
+
+        set_config('perfdebug', 7);
+        filter_manager::reset_caches();
+        $filterman = filter_manager::instance();
+        $this->assertInstanceOf('filter_manager', $filterman);
+        $this->assertNotInstanceOf('performance_measuring_filter_manager', $filterman);
+
+        set_config('perfdebug', 15);
+        filter_manager::reset_caches();
+        $filterman = filter_manager::instance();
+        $this->assertInstanceOf('filter_manager', $filterman);
+        $this->assertInstanceOf('performance_measuring_filter_manager', $filterman);
+    }
+}
