@@ -178,11 +178,21 @@ class textlib {
             return '';
         }
 
-        if ($toCS === 'utf-8' and $fromCS === 'utf-8') {
-            return fix_utf8($text);
+        if ($fromCS === 'utf-8') {
+            $text = fix_utf8($text);
+            if ($toCS === 'utf-8') {
+                return $text;
+            }
         }
 
-        $result = iconv($fromCS, $toCS.'//TRANSLIT', $text);
+        if ($toCS === 'ascii') {
+            // Try to normalize the conversion a bit.
+            $text = self::specialtoascii($text, $fromCS);
+        }
+
+        // Prevent any error notices, do not use //IGNORE so that we get
+        // consistent result from Typo3 if iconv fails.
+        $result = @iconv($fromCS, $toCS.'//TRANSLIT', $text);
 
         if ($result === false or $result === '') {
             // note: iconv is prone to return empty string when invalid char encountered, or false if encoding unsupported
@@ -238,6 +248,36 @@ class textlib {
         return $result;
     }
 
+    /**
+     * Finds the last occurrence of a character in a string within another.
+     * UTF-8 ONLY safe mb_strrchr().
+     *
+     * @param string $haystack The string from which to get the last occurrence of needle.
+     * @param string $needle The string to find in haystack.
+     * @param boolean $part If true, returns the portion before needle, else return the portion after (including needle).
+     * @return string|false False when not found.
+     * @since 2.4.6, 2.5.2, 2.6
+     */
+    public static function strrchr($haystack, $needle, $part = false) {
+
+        if (function_exists('mb_strrchr')) {
+            return mb_strrchr($haystack, $needle, $part, 'UTF-8');
+        }
+
+        $pos = self::strrpos($haystack, $needle);
+        if ($pos === false) {
+            return false;
+        }
+
+        $length = null;
+        if ($part) {
+            $length = $pos;
+            $pos = 0;
+        }
+
+        return self::substr($haystack, $pos, $length, 'utf-8');
+    }
+
     /**
      * Multibyte safe strlen() function, uses mbstring or iconv for UTF-8, falls back to typo3.
      *
