@@ -186,8 +186,6 @@ class qtype_numerical_edit_form extends question_edit_form {
     protected function unit_group($mform) {
         $grouparray = array();
         $grouparray[] = $mform->createElement('text', 'unit', get_string('unit', 'quiz'), array('size'=>10));
-        $grouparray[] = $mform->createElement('static', '', '', ' ' .
-                get_string('multiplier', 'quiz').' ');
         $grouparray[] = $mform->createElement('text', 'multiplier',
                 get_string('multiplier', 'quiz'), array('size'=>10));
 
