@@ -222,12 +222,14 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
     $modinfo = get_fast_modinfo($course);
     if (!empty($modinfo->cms)) {
         $section = 0;
+        $thissection = array();
         foreach ($modinfo->cms as $cm) {
             if (!$cm->uservisible || !$cm->has_view()) {
                 continue;
             }
             if ($cm->sectionnum > 0 and $section <> $cm->sectionnum) {
-                $activities["section/$cm->sectionnum"] = '--- '.get_section_name($course, $cm->sectionnum).' ---';
+                $activities[] = $thissection;
+                $thissection = array();
             }
             $section = $cm->sectionnum;
             $modname = strip_tags($cm->get_formatted_name());
@@ -237,12 +239,19 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
             if (!$cm->visible) {
                 $modname = "(".$modname.")";
             }
-            $activities["$cm->id"] = $modname;
+            $key = get_section_name($course, $cm->sectionnum);
+            if (!isset($thissection[$key])) {
+                $thissection[$key] = array();
+            }
+            $thissection[$key][$cm->id] = $modname;
 
             if ($cm->id == $modid) {
                 $selectedactivity = "$cm->id";
             }
         }
+        if (!empty($thissection)) {
+            $activities[] = $thissection;
+        }
     }
 
     if (has_capability('report/log:view', $sitecontext) && !$course->category) {
@@ -347,6 +356,7 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
         }
         echo html_writer::label(get_string('participantslist'), 'menuuser', false, array('class' => 'accesshide'));
         echo html_writer::select($users, "user", $selecteduser, false);
+        $a = new stdClass();
         $a->url = "$CFG->wwwroot/report/log/index.php?chooselog=0&group=$selectedgroup&user=$selecteduser"
             ."&id=$course->id&date=$selecteddate&modid=$selectedactivity&showusers=1&showcourses=$showcourses";
         print_string('logtoomanyusers','moodle',$a);
@@ -474,12 +484,14 @@ function report_log_print_selector_form($course, $selecteduser=0, $selecteddate=
     $modinfo = get_fast_modinfo($course);
     if (!empty($modinfo->cms)) {
         $section = 0;
+        $thissection = array();
         foreach ($modinfo->cms as $cm) {
             if (!$cm->uservisible || !$cm->has_view()) {
                 continue;
             }
             if ($cm->sectionnum > 0 and $section <> $cm->sectionnum) {
-                $activities["section/$cm->sectionnum"] = '--- '.get_section_name($course, $cm->sectionnum).' ---';
+                $activities[] = $thissection;
+                $thissection = array();
             }
             $section = $cm->sectionnum;
             $modname = strip_tags($cm->get_formatted_name());
@@ -489,12 +501,19 @@ function report_log_print_selector_form($course, $selecteduser=0, $selecteddate=
             if (!$cm->visible) {
                 $modname = "(".$modname.")";
             }
-            $activities["$cm->id"] = $modname;
+            $key = get_section_name($course, $cm->sectionnum);
+            if (!isset($thissection[$key])) {
+                $thissection[$key] = array();
+            }
+            $thissection[$key][$cm->id] = $modname;
 
             if ($cm->id == $modid) {
                 $selectedactivity = "$cm->id";
             }
         }
+        if (!empty($thissection)) {
+            $activities[] = $thissection;
+        }
     }
 
     if (has_capability('report/log:view', $sitecontext) && ($course->id == SITEID)) {
