@@ -1,18 +1,18 @@
-<?php  //$Id: define.class.php,v 1.2.2.1 2007/04/04 04:38:47 nicolasconnault Exp $
+<?php
 
 class profile_define_menu extends profile_define_base {
 
-    function define_form_specific(&$form) {
+    function define_form_specific($form) {
         /// Param 1 for menu type contains the options
         $form->addElement('textarea', 'param1', get_string('profilemenuoptions', 'admin'), array('rows' => 6, 'cols' => 40));
-        $form->setType('param1', PARAM_MULTILANG);
+        $form->setType('param1', PARAM_TEXT);
 
         /// Default data
         $form->addElement('text', 'defaultdata', get_string('profiledefaultdata', 'admin'), 'size="50"');
-        $form->setType('defaultdata', PARAM_MULTILANG);
+        $form->setType('defaultdata', PARAM_TEXT);
     }
 
-    function define_validate_specific($data) {
+    function define_validate_specific($data, $files) {
         $err = array();
 
         $data->param1 = str_replace("\r", '', $data->param1);
@@ -38,4 +38,4 @@ class profile_define_menu extends profile_define_base {
 
 }
 
-?>
+
